(function (root, factory) {
    if (typeof define === 'function' && define.amd) {
        // AMD. Register as an anonymous module.
        define(['exports', 'echarts'], factory);
    } else if (typeof exports === 'object' && typeof exports.nodeName !== 'string') {
        // CommonJS
        factory(exports, require('echarts'));
    } else {
        // Browser globals
        factory({}, root.echarts);
    }
}(this, function (exports, echarts) {
    var log = function (msg) {
        if (typeof console !== 'undefined') {
            console && console.error && console.error(msg);
        }
    }
    if (!echarts) {
        log('ECharts is not Loaded');
        return;
    }
    if (!echarts.registerMap) {
        log('ECharts Map is not loaded')
        return;
    }
    echarts.registerMap('浙江', {"type":"FeatureCollection","features":[{"id":"330100","geometry":{"type":"Polygon","coordinates":["@@XBFBF@DGFWFK@CDO@MCE@CFKBID@HFLBAKECAKBMFCBOCCBKSMDE@MOKEG@EMGIACACCBCDCNBFI@Q@ALA^IHCBGDBJHDBTBbLjHBE@MIGOAOYDAGULI@CVKPMHANMLR@JhHFPHTDNÎAÈBRA¨UFAHGFMBk@[BkJWHGPMyqq{u_AEcuWkEYCCKAQGCAIBEH_@IEC@A@CHMHkDICGAUFGDGLGHaHGGGDOAEOBOEACCAAM@CICCAQA@aEIBAFBJAFQFE@AAB]ECCACBBNABM@ABBF@DIFEFCNCDEAAAU@OECAEGIHC@@GDIAA[@@GIGEIGIKFCCCBCPADEBQGGGCABCL@@AGMIEEIIE@GDGJCJAJFJLHBZQLADCDGBEAMCMHEBC@SGECGMGAENQHAJBFAFYAE@ALCLM@MLMCK@EDEAEFGCGGCYBGQ@ICIMGCCKG@MGCOS]JCBEBEDCCCMGICAGAGAQJ@NGPCDGFCAEKEAE@GFYBKFOEKKOE@CHI@AMKOUECC@IFGB@HEFIDC@KQAGEAIDAAAI@ICCDG@EAIGMQQIMQKGAQKQ]@GDE@AMMEAEDIFILEDEAUK]DWCCIIMAGJKDWMK@WACE@C@CCCCIAEAAC@GOCWCGDABKDABANG@MEAEIIC@YBEAOIGAKICBAFADMDCFABKCE@QNGDC@@ICGBADETKCGBGDOHALKBCAG@EHKACFGJGLBHCDDGFADBBFDJBDADAFAFCHGL@FCNCLIBWAICEYDSGOACAE@UFEAAISFEGYCUDCBGHGDCAGDIAIDE@IESNKDABBFABUUE@GDCAIIACIAKIAECAE@CAESOMGWAKHO@QKIMCCA@CBCBECC@CFEBEEQIG@AHE@EAEIAECKGE@MDAASEIEEEDGPKDGTODEACCCMEQ@@C@AOEAEBWACKIKWDEAIBEBEHCDOCGEEAEBEACCAM@EBGJC@A@AK@QAEKEGAEDELE@KAIFGAMDCJEBCAQSOG@QOUKIIAAAAGBAXOBCBOECE@IDGAMFIJGBMBGAGKQAOBAAKGK@IDCDEDAAICKIDCBGCICISWEIODC@OGYBCF@LCHIHCBIAEDCLIRFJGPCNDH@DEPOLCHBHEF@PCBQC@EHGKSOCEAE@C@EEC@AB@JEHGDI@IfKDGCOYCCMBC@GKSCC@KFA@KWGE@CBCJCDCBEFCBCAEBCGIAKBEGSDIDAH@JKFK@EGSFABCBACEMCaMAA@CLK@I@CE@CFAB@KBCAGIIIA]@KFGAEA@CFQACGAAAAGEAECCIECWG]HKAA@DRGHCPCDGFABDL@BGDKEUDEHIDCKDG@EBAAAHA@AACE@ECKM@E@CDADAFDDAHITKCAAA@QAIFKCCCAE@CBCLMACBEAAA@EHGBC@CIUYDAHKLCDODMLCBKII@EEMBABAJFRKBE@cSWBCFM@ECACGEC@MDK@OGS@OIMCcESICBEPGDEHIHAH@JAJFHILGTCAABKLEHGAA@OTCBEFADFFTHDD@FABYFCDGJAB_FGJMFGJMJCFEDOGCICAE@OHQGQOGKAKCCIEMAGGEEME@ECGIAIDIAeYMACOEAACAACEEAM@C@CECOJMAIBM[QS@GCKGACCIOCOQMAMFYRGDQCK@eG[IG@K@CHDFHFBHC\\EBGAG@GNEFAFKNPPBHGNCJEJ@BFJ@HBFD@NEDBDKNMJEB@BBAHIVMNKPGHFNGHUTBNEHIFOEAJABC@IAIHEDS@UECBMBAHCDUDK@GA@DJRBJADEBGBEAQGGFQBCFGDOAQMMBSNIPEBEAEBSLMJAFHLAFMFEDOBCD@B@BJJDFBHIFIDQCIBGFCLKBGDO\\EBWDADAHIP@TDCNBJDHNNNHLLLDFDJB@REX@TDLAJGJANDFJBCDBLHTMFARDRHVLLB@FAVDJBPEPHR@NDPJD^PXHHBJRDJPTFADBJNNLBNFHFBlLN@dT\\IHGHEH@HFJHFLTRLHDD@JBBLJBBBNRLBJPPdFLNBLDHNHHJDDJDBDBLDHBP@FGLDJEPKJCHB`DRFFFDXAD@NNKJQD@DFN@LXHPGJEJBHFDLRNHDLNRLDBJHNHVRHP@bCJAPCDCLBDDDNBTELAHFBHHFLCLKTAB@ETBTCDBHDPHLDJEJIL@DFH@JAFGHDFLHJXAFKBKRDFJJ@FEFKNEDMBCLAPCFAL@NGN@D@HFLDDNDJ@FD@H@JJLDFDP@HCBGCS@MBGFIBGEKAGDIHCDDJBDJHXFxVVFDHL@DDFLJHPFBB@HGNKDO@MBCDEJGXEJ@FEDKDED@FBBPDGLAPM^APFHBH@LCP@FTDVLTRPBJDLLNFDLAD\\PJBBABMFIJFFBF@FGB@ZDB@BEAKBOfIJKLAHIFCHARATBDCDILCF@FBHFNPRLPDFADCFCHAFELGRALIF@nAHADGDAD@FBD@JGHAJBRG\\@DPDDJCF@JDB@FCBABMBEHBJHHPPjCFEBADFNJNJAJEH@HBLHJAD@XRPPFLvPD@PILGDCBMHIN@hLLFJLLFH@HBFLH@XFFFHFJDFDDJJ@LPJZJ@XGT@NBN@PC^IHBJDNHJBDDBFCLBHRNDHJJ^HFEFGBKNMDATCJBRJLANBTLPPDBJCFCBOWCCAACJe@ECCCA@APCHCLAPDH@LD\\TJRVRVHBBBFCFEFCJOP@N@JJBDFBJLX@FGNHD@DBVEN@JCJGJKXC\\@DBBPADBHDHLLCHGPQ^CJ@HBb@DCBEEQA]ACICAAJGdEVMHBdJF@VMFIHCJ@JDBHDBBAB@FQLOJEDIFAJBF@FC@CKECG@IBCVANEHAF@FFDBJED@RJFBH@HEDEBOFCHAJBJAHG@EFITEHBBBJLPLHBbCD@FIHEXAN@VCFABCBEH@NDNBBBEHHDDH@HEJEDELBPAPBFJLF^PAFBDBfCBCGIBGDCPCFGBAH@PFjHHABEAMFIVFDFFBL@HFCF@HB@JEBDEFBFIHHBDCNFGD@@BBADFFXDAJBFHFBADKBCBANJR@FA`GXBTAXBJCHHHADJRFD@DF"],"encodeOffsets":[[123188,31253]]},"properties":{"cp":[120.153576,30.287459],"name":"杭州市","childNum":1}},{"id":"330200","geometry":{"type":"MultiPolygon","coordinates":[["@@@BBAAA@B","@@EB@BDLGFBDDD@DH@HEFD@DFBBAD@FHCDBJPFFDD@HABCFAD@BDFA@CDEAC@CAAMBW@CCDABCEGBCAAG@CCCCE@IDEEEI","@@IBAHIB@DJJTFB@@CKECCBAD@BCFAEI","@@@DB@H@FAFHB@@ABA@ACAACBAAAB@@AEEIBCABFGDDD","@@BAC@@B","@@BAAAADB@","@@BBHBDC@CCAE@CB","@@GFAJ@DBFJDNIHBDG@ICEQ@","@@BDF@BA@ECCE@AB@D","@@FBP@B@BECGEAEAEBCBAD@F","@@@ACEC@AB@DBBFB","@@ABFBACA@","@@D@AAA@@B","@@FA@EKIGD@BD@@DDHD@@BB@","@@@FBBLABCAC@EBCF@@CIA@CEE@CC@@ACAADGB@DBBDBAJBBCD@DHB","@@BA@CA@@AEABFD@AB","@@BDDBLIAAEDAAABC@","@@BBDAAACB","@@F@@ACAAD","@@@HD@HABFHDD@BBHADAFGHBFCBCCAKDEAGDM@A@HCIEBCA@G@BDABEC@B@B","@@BA@AEA@BD@@D","@@CD@BH@@AB@H@BCACBAB@NJ@A@CDBB@AA@CC@KCI@GF@B","@@@BJBDDHBBACCH@@AEA@CCAFAA@@C@AGACD@BEAEB@DB@BDF@EB","@@A@@DHBBCD@@CBAC@CBABA@AB@@","@@@BBDBFJABE@AGBCC","@@ABBBFBBAB@FAGCA@@DCA","@@DB@BFB@DDABAACB@@AC@@CI@@BA@","@@CBBBL@DACEAAGF","@@FBFCDIM@EBCAABBDFBBD","@@@BD@@AC@","@@DBBACAAB","@@@BB@@DJBF@BECEKB","@@@DA@@B@BD@DEDABCDAGAADEB","@@BBHBFADBBEHBFCCA@EG@ACA@CFA@AACAEH","@@E@ABPDBED@@AFA@ACAK@EDBD","@@CB@HFAF@HACCIA","@@@DF@DAF@FA@CCAADC@AAA@AAE@ABBB","@@FBDDH@EC@CC@EAAB","@@@BFBHEC@IB","@@A@KBBBH@D@BA","@@EN@BD@@CHGCCA@","@@FECAACCA@ABACCAHBJ","@@@JDBB@@CBABCFBB@AECAABIB","@@BBF@DAB@AFB@FEHAACFADECB@CAAGACBA@AB@BOL","@@D@DAJDBBDACCBEEDAECC@GEAIDCD@HBBD@DF","@@BFHACCC@","@@@EC@AFDB","@@BBBAA@A@","@@@CCABF","@@TFH@DBHABBB@H@@CGCCE@GFGL@DAACDEA@CA@ABCFCEAAGA@ADEDEAA@IFSXADCBCD@H","@@h^VBTHH@JA^MFKBOAUMIaMcKWQKMcOeUGEMQAOIIYiY]QKeGM@IJYFWBIAGGESGUii{utaPELAlHJHVTPDL@NEHIHC`CZGHK`qRKJMBG@MEGUOAMJSLI@ACEOGcuEQHoFIZULKDSCKS_MeWEGC[WOUCYFCACCACICQBEFChKDCBE@EKQKQGUCOBSFGV@XETBHBH@JANEF@BAAG@EAKBCF@BCACWB_OAABCACMBBKRg@EDA@ACCGmAAGAg@WK@A@EX@FAHKJKXO^ODE@ECEEAI@@ABELGFuAEAEGGQCGECC@ADAV@DA@EDACCUMCEC]@GCGI@SKUFKDCBCFBZADe@QCEDCDBHTR@BCHEBMZGDSAMIIIMIKGO@SDOJORKHSHE@IEQCQDIFENQAfe}WÇvfHUAICk}GGG@gHoFOBMHSPIFKBa@SCKBEAOACBCDCDBFFFCPBHKHGJSTGDCASOMCKE@GLK@E[mEK@CFEAEDCGGCGKIOCKGKOCGG@AB@LABMDMAAAHKCE@GEEBIGAG@ABAFKBEHKDEJFD@BMHO@CJFHBNAX@PNLBBCBCCEA@B@DCBEAABCF@HGHONITAFBRKBADCHCBOBYC{FIDGFBDFFHBFJIFAHMNGRLLDRD@NAH@ANEL@HDNJLCFFF\\THJ@HAFEBMGELBBLFFFAN@JCJF@HBHJJFHHDBLBRP@P@FEHALDLBBD@@DER@JBJEFUDABBL@HBJ@JNRBD@DIBEFABBJCDLF@BCJBLR^@BEDOFADCFBDLABB@HDDJBFFEP@FIFADBDBDI@GCEAYPM@IAKDQAI@[HS@IBEFCLIF]BG@ADBPJH@FFHGN@HKCCDCAEDNFALBBHBAJHABDADC@CBCACBFL@DEDGBAJEHGBGFGAEAWJCHF^CRKLSdEBCBWOMCWKIAWHKAKDEDEJBDFDH@NDJ@JF@FOLBJDLLDRBNDHDDDAFGDIBQ@KLCH@BJNDDLBJFJGB@DDUd@DBBPFXCFANKHBNN^PDFBJLFFDHRPHBD@DEJKLDLJH@FFJBFABKHIDG@KLGBIAEBGFCHCDG@AIA@EB]XULADDHE@EDILCJGHDBJB@D@FRT@DAD@FFHJDDJHb@TRJPBJADBHFHLH@LDBDBLFHDFSHCNEFULE@GAGAIDC@EKGAEBACGLFHABFJABC@EE_ACB@DMBCFCDG@SP@JFDEfIDEJKFONBHDFBDCDITEDIDG@CEG@ORAFBHGLM@ABBDJFDDDJQlEXAN@DMPGZo_rUf¦\\j\\LxPfHf\\P`hpxjpXÀtPDÌ¡n[XCKZGbKPCbIjW¶pelk~~hRkNUROiJKxl_H@DZA~glar[idENHAHDFnbBDZLJBFADGFCHADCFQBANADAHQHEBE@S@WDKDAFAjBPAxBNC","@@X@FB@HA@CAABMH@BJBDDCHED@DDDBAFABBADE@@DDHDBDA@A@AFCD@DADBBAACBAB@FDDAACACGEBALG@AGACCK@AA@C@EDCFCDAH@DDHBDC@AB@VHBA@AGGACACCECAABA@CGIEE@CBCAABAFA@CCA@AFG@@CDC@AEA@GACEAEBCHA@CACGC@AFA@AACBEECBABBDHFAJFBADBDC@C@ADBD@BFBF@FEDFDA@DD@ADE@@D","@@ACCA@BDDED@@FBBE","@@BDBA@AC@","@@@DD@BECB","@@D@BAGAABBB","@@CBPBBA@AGAEB","@@@FBFNDBAFB@DHBBADDB@BAHA@AKE@EIBEC@GIA@FCBCA","@@F@BAEAA@@D","@@A@BDDDDC@AAAA@A@","@@CXBFBBFBv@XGPQHA@C@ACAODAADAAIPABCACCEE@C@AA@CF@BCEEC@@ALC@CCEEBAABCAAKDEAIFDFE@@B@DDBADM@GGA@UXIHCB@H","@@ABB@BAAA","@@CF@BDB@CF@@CD@ECCB","@@C@@BBBD@BCBACAAD","@@BDHCCCGACDFB","@@DFFA@C@ABDB@DCAABCACABACEBEAABDHCD","@@BBDA@AE@","@@CFBBHAAEA@","@@CFBDB@FG@ICBAD"]],"encodeOffsets":[[[124865,30450],[125115,30114],[124909,30037],[125165,29553],[125179,29557],[124827,29700],[124949,29988],[124939,30621],[124955,30627],[124935,30618],[125091,30616],[124686,30717],[125033,30576],[124935,30341],[124956,30333],[124928,30282],[124927,30270],[125014,30213],[124939,30213],[124904,30210],[124902,30198],[124909,30181],[125117,30168],[125137,30154],[125154,30166],[125164,30170],[125171,30169],[125188,30160],[125111,30112],[125126,30085],[125139,30093],[125156,30081],[124901,30112],[124930,30117],[124932,30047],[124914,29989],[124932,29998],[124957,29988],[124967,29981],[124972,29965],[124971,30520],[124965,30519],[124904,29933],[124912,29930],[124935,29937],[124992,29915],[124991,29908],[125015,29888],[125007,29890],[124879,29889],[125007,30608],[124955,29879],[124987,29829],[124963,29800],[124913,29784],[124945,29748],[124953,29723],[124857,29733],[124769,29771],[124708,29771],[124714,29781],[124744,29734],[124730,29736],[125182,29574],[125188,29574],[125194,29580],[125211,29579],[124854,30364],[124919,30343]]]},"properties":{"cp":[121.549792,29.868388],"name":"宁波市","childNum":69}},{"id":"330300","geometry":{"type":"MultiPolygon","coordinates":[["@@CBCDBNBBJ@@CBIEE","@@GBBDDBDABCCA","@@G@AB@FBDN@HABCAAE@CA","@@I@CB@NCDIDAHBHDHFHdTF@hQF@TFVA@CACCCYSUEA","@@I@GBIJGFSDMAICKGEAQFCDAF@XDHHDPHTLJLFFLDJ@LCPAvFLAPIfg@CCGGCYKQGqI","@@A@@D@BBBDAAC","@@ABDDBAAC","@@B@A@","@@A@@BDBBAAA","@@A@@DDB@CAA","@@A@@DD@BAAA","@@@A@@","@@A@@FD@@CAA","@@JBBAACE@CB","@@@BJ@@CCAED","@@DBD@BA@AAAG@","@@DBDC@@E@","@@BDF@BAECCB","@@DDDABCCAEB","@@BBB@@GA@AD","@@@B@BFBACCA","@@KFMLA@@CE@sVAAACNQDIAAIBSTOHAFFFDBJCD@GVBBNAFCJA@DIDADDBF@HEVEBABCDGBEFCN@DAHIBACC@ANKAA","@@HEGIGDIJHD","@@LAFGIBEBCF","@@C@CF@BDBXEDC@ICAE@GH","@@PGFEAAMCE@GDBHEHBBD@","@@CFBDDANA@A@ECAA@GD","@@F@HABAAAB@@CB@BCC@ABC@GB@B@BEDBB","@@@FDBDAEEA@","@@@DFDDBBAACGC","@@HHBAD@FAB@IEKB","@@GDAHBLFFfRXJHBJANCBC@EAC[QICQEOE","@@@@BAACGABDDB@B","@@B@DACAAB","@@GC@AC@DDHB","@@DFH@ACIA","@@DBD@LDDAACCABGBA@AACCBACAAC@EEE@AHC@@B@BHFAB@@A@@BFF","@@CAA@DB","@@DBHABEAACDID","@@FDD@CECACB@@","@@SCAJHBDALHAEDA@CAA","@@LFDDHZFDHBDH@BEBCD@TEHFNL@PHBBBFFBHHHDBDBPDHhTF@DATFHFJNDBRADHFHRPBDJL@DEDDJ@@BCDCDFJBJLDBDE@I@EBARAFD@DDJCB@DFD@BGH@PDFPH@FIBEF@Z@DHLADEFAFBDJFN^FRCJE@GHEFBLEDNNHBJHLBH@FCHGNIR@FRLNPH@BghDJZJJAHBJMDIDADD@PBDAH@DTPB@FIDCT]DAD@FFJBHAHDJHPHJJdJFANDHABDBBBAHK@CDC@GGEDCGMBEAKBAHEFLDAHBBD@PMFAJANDHNFDJBj@DBDH@DGHBFFHNHB@B@DIL@PNFBBBBJDDB@@CLBXBTCDCF@HCJAFBDFB@D@JCD@B@FADFNBHCFGBE@KAKDA@KJELCDEBB@ADA@EDCFEHAL@NAHBREFCRDFD@D@DHJBHAJFXPFHA@ACGFEHAL@LDfdN@JBHAVDHABADQ@CPHJNDHPFCHGBQBCB@DBHBFJNFZJF@ZAFGFBHDD@FBDDBH@DADALDFABBJFDPAFCFAHKFCB@H@BHBAFFHPHNDHAF@LJDAJPTTAHIFADFJADCBIDADSFIF@HBBdPNDPAFJCDAHCDCFABBFDHJFRDBFCJEDAFQFCAC@@LBLDHLDFJHLJJBBHDBBGTCBGBIBEJJR@LI^EFAFALCRYFEDIPK@UDINBHADOBMESHCD@BRFJLBBAN@D@B@JCJIFG@M@OH@DBDAL@FLDJLAFCBEACBEHCLADBFLBBB@DABADBD@PFFFDHCP@RIDAAGFILIDB@FDJFLAHBNGLEDCFAHNNLB@FBJAFBD@LFDB@@A@IBAHADIFAHN@DGD@DDFDBFCLLLHBD@DGFB^ABJLDBBFCF@DFFAHDBJAB@DL@DCF@DHP@BGLBNJLL@BPHFJANDPBHBD@LKD@B@DDF@PKFKHICCBEDCNEHDNEJAJMNCLENSPDFERABFFFF@JCFGDAD@DDVB`@LAHBFF@BANBFEFEL@BFBDFHFFEF@HEFDNDCH@FOP@DFBHBNJJAFEPCLDXBDBBFLBFDFHANBD@HDFHFLEJGFAN@JBJJLDLCFGHADACMDKD@HDJ@D@LGLBJKJALJFEAKCEBCFED@nKDIBKHGPIDGCEEKIKAELOHBFGB@PBJGDE@K@EFEFCFG\\CH@FCHAVBLDDHDFZTF@\\CJEJCFHCHADNFDA@GACAICEAEHEHOJ@H@HCH@JBFCDEHA@EJADB@JBBDBLCJBDADIL@BFDDBBFABDDDF@LELAXDR@JFBBAJBHDFHDFHFL@F@NDHFFNJJRDBFCH@PGPUTBDBFBDAACBCF@DDD@HC@ADELGJKFA@KAEDED@HQDMF@BEH@FAFA@K@APILCBAGEFEBKDC@EFGTBDCBEEAEM@CBCB@JBPAZQHAJI@AKCAABGIQ@IMCWBCCKI@ABADA@CMCGAEFAGGAHKLIDMMkBGDB@EGDEMMUq}eGECGICG@IAW@UCYA[MYaigaW]gQmK}SkoÄ¥PGXCpBdJjRNDPBLAHCBC@GC[@IBEBCHEfCPCFEFMDO@KG_IUGKGEKCU@SDEAACA@@CCE@CCIIGBAACGCA@@BA@C@@ECCABCB@FABBBDBABADC@@DH@FFFAD@BFADBDD@@CHD@BA@JF@DBBKB[EO@cBQFK@EBKJ]XK@CIBEDOVofħísGQMQk]iOY_OUkkGGUEGCCGDaLIhHEXADABCDWFQHIDCLCHEBC@KEOamKWEMAGDc@iCYEMIIQKMEY]GGGGAGBOFQ@ECGIIKGSi@EDCfQDE@CGUOOKSCMAkCQMaSOKGQE{KE@kNG@EAafEBGAAB@HCFQJCF@DDFADMHCHQB@BFFAHIJHF@DABI@CBLFCF@DJHHP@BGHUNAFHJRLJ@FGHCJDDFBHYVEDKJIPCZ[VIJIVGLCBIBQLAFKJ@FFL@BAFMFEFAFFFAFNV@FCFGLKJQGG@MFABHF@DADGDEC@A@GCIBGAAGBADCEI@MHEBICIIGCG@CBMXKLCF@FDFHF@P@HCFWNC@CIQKOCCGIAACEBCCGBEDKLC@KAG@UME@AAKFI@ADEBAAE@cCOEEEAEDGFEDIAIEGIAEBAFEBGBUCQGCCBUECI@MMKACKEEGACCIUK@CEAKM@SHO@CDBF@HOPELMA@PAHEBUFKE@IAAO@QEUCGCAGBCPFBA@CEGCCQIEG@CCECAK@CCBAJ@BAIG@ADECCBCH@DKACODGBGAMBCABCCAKJG@C@C@GACCAGE@GAIFA@@EAEA@ADGBAG@GECCDBHABMACB@DNHBBABM@IDGCCDGFCFCBGCOQJILACMCAMDGAG@@BEBCA@GCAKDGLSJKDCAAKCCSDIDE@A@EFFHAVBFB@DAJKLHBFABGFGBG@GFAF@DDHCHC@M@GFI@AFCNOFLNJH@FEDME@JANIBCDCDBFIDCHGDO@EBADBJGFCFBDALCDG@GHI@IPHFJCDD@DNFBNDDCHNJGNFJCHFB@D@BEAAD@FHDAPKDABBPJH@FEDGBCLBDURADDDGBCFAA@ECAEBOAIEC@BDCDGDDJFHFLBDD@D@@PJNCHuHG@IFKAEDAXCH@HDF@FEFCHBLFDD@HFBBHCBB@FDHFDDJ@BGHGNADFFDNGHE@AD","@@B@@AA@@B","@@@@","@@@@@@","@@@@@@","@@LDD@BC@CFA@GDCCEIGS@@DGAEB@BDFJBBBAFBB@DBD","@@JDBAAACCED","@@ABD@HDDA@AEEGD","@@DBBACAAB","@@FBBACAC@","@@DDDAHBBACEDC@AEBKCAJ","@@DBDDH@BCHA@GCCQECB@DA@@BDDABA@BD","@@@FDBFBDDDEJ@@CJ@BAC@@CA@IA@BKCGBCA@D","@@D@C@","@@@AEDDB@ABA","@@D@C@","@@BBBACA@B","@@D@DAG@","@@@BB@B@AEA@@D","@@@BD@@AC@","@@FFHBEECAC@","@@CD@DJ@DEEA","@@JRHB@EDFD@MUIC@DA@","@@B@BADDDBAHH@ADB@HBFCFDDABCIGEGGGGAECIABDADCAAFGABDDDBAD@DD","@@FHH@JAACEEB@ACDB@@@CCCE@CDDDAFCAACAB@B","@@BBD@@IECA@C@DJ","@@NB@CD@BCCAE@AEG@ADA@AFBBDA@D","@@BBBAACAB","@@DDB@EC","@@BBFBB@DDF@AABAACC@CCC@@BC@AB","@@B@AAAB","@@FBDAFBBA@CBAGAODBB","@@DFFCECC@@B","@@@BJ@IA","@@HFFABAEGAAEBBBEB","@@DBDCBACAE@@F","@@EL@BABAJFDLA@BHDCDBDB@DCD@DE@CFAACEADIEECAKIICC@@BDDBD","@@C@@DDBBFFBDCBBDACAAEDCDAB@CEA@GHGB","@@@BDDF@HDB@CCCAAEG@","@@FBF@ACAAI@BB","@@JFHBHABACEI@CC@ECAA@ACGC@DBBBDAJDB","@@@FB@JI@ABA@AGACJ","@@BBDAFDDCFABCHCBICAGACDC@AB@DAFEDC@AB","@@HHLDDA@EE@IGE@AB","@@@@@AABB@","@@B@A@","@@B@@ACB","@@@@BAAA@D","@@DDDC@AE@AB","@@@BB@@AA@","@@A@@BFBBA@AEA","@@A@DDD@DAAACBCA","@@B@@AA@AB","@@@B@BDEA@AB","@@DBBA@CCBAAAB","@@E@DDBC","@@FD@AEA","@@DADBDAEICAE@CAEBE@BHLBBD"]],"encodeOffsets":[[[123981,28693],[123949,28698],[123960,28692],[124095,28635],[124005,28609],[123812,28483],[123801,28481],[124061,28478],[123747,27716],[123759,27710],[123749,27703],[124058,28470],[124037,28394],[124034,28345],[124085,28361],[124101,28366],[124096,28393],[124055,28441],[124072,28577],[124130,28512],[124128,28505],[124014,28103],[124001,28154],[123964,28144],[123985,28088],[124020,28133],[124035,28128],[123969,28103],[124180,28680],[124173,28672],[123959,28680],[123950,28651],[124132,28608],[124137,28601],[124081,28591],[124033,28585],[124020,28589],[124156,28503],[124159,28502],[124122,28481],[124134,28486],[122507,28333],[124053,28458],[124042,28453],[124042,28453],[124042,28454],[123990,28459],[123998,28468],[123999,28473],[123908,28504],[124062,28421],[124054,28427],[124039,28429],[124039,28437],[124069,28411],[124072,28413],[124077,28409],[124081,28412],[124082,28415],[124051,28359],[124106,28316],[124100,28315],[124105,28326],[124114,28273],[124109,28288],[124127,28277],[124041,28288],[124077,28294],[123953,28296],[123952,28301],[123961,28297],[123948,28334],[123843,28327],[123834,28319],[123828,28313],[123836,28308],[123840,28303],[123876,28314],[123806,28359],[123819,28350],[123821,28346],[123725,28310],[123740,28336],[123727,28351],[123711,28355],[123652,28245],[123639,28233],[123638,28233],[123632,28225],[123617,28215],[123603,28182],[123603,28186],[123602,28183],[123588,28169],[123737,27693],[123733,27693],[124137,28613],[124137,28613],[123799,28377]]]},"properties":{"cp":[120.672111,28.000575],"name":"温州市","childNum":99}},{"id":"330400","geometry":{"type":"MultiPolygon","coordinates":[["@@DB@ACGA@ADBD","@@@@@AAB@@","@@@BB@DAAAA@","@@B@BAE@@@","@@ABBDFAACA@","@@R@@IBCPFPEBDH@FCHAD@@BILBB\\BDLEBBFCBBBDADBD@HADMHABAEEBAh@BCN@CAFIAABC@@@CA@@CB@@GCABCHBBEAADEB@DQB@D@@CCA@EA@@AMA@AAABCA@@CD@@AAEDGE@BGD@BGB@@KAADEFE@EAkAIDBH@@EA@ACGB@CG@CC@CCGDCBG^CBAAE@AHAJ@DCDC@@A@ACFACCDACACDEEFAACEEDCCCB@ACCBBCCCHCCCEBCEC@CGE@CECBAEBAA@ACE@EGACHAGEHECEHABB@DBADFA@BDDBBA@ADAB@ADBANNFBBC^ILQDKPDCHA@ADA@BEC@CB@@DBBHB@CFHBDEHAEN`LCLD@CDHDFD\\@dPAAB@@A@AD@AABADCD@BALDDFBABCJCDBBA@ABAEGAKCCB@BBB@TCBDFEACBA@CDA@DB@@IIKGQCa@IC@I@CEJMZCHD@ABAFBBDRAFCDBFA@GFDLBBBBCDABCLDFBFD@DDBDABDBCJKHBCNDFJDX@BAHOBADBB@@GDAAADEDGBOJEAABA@BDABBDAAABABBXKDATSB@BBDCB@ACBEAAB@AADECE@EECBECEBEB@BIDAAEDA@GF__CCCYeIKOIUGMaOk[AI@KAAIC[EECIGKGSwW\\kluvuhaOC¿soWwigoO_e[eG[i¡[Sq@WBTSBKFiXQRIXAl@\\AnELGHEBQFPYBÇA¿BO@M[GOIg@IKQMNGBONUL@DKJHVCBPZPBJH@NAFiGaKSAOKCHGD]JKB@B@REJMACDADHFJBNH@FFHPL@NCFTNALDDAPEDANBLFDBLKAGEC@AJEL@DDF@NCP@DELEXCHE@EAWAAB@DFNA^CZEJ@FH@HDJBFFHDFJ@FCF]\\BN@JLH^@PDDBN`@JHVEJBHBLJDPADCDELED@DFFAJBHBDFHPDFVFL@xHNDV@JBAFCFIHIDCDBFFFLAXBJDTR@DDDNXAHEDADAJELCNKXL@RCBBF@JCXG`dpHNNRHHBHJHbTFJLHBANEXCRDRLTCPBB@AEBANEFA@PFD@LBFB@DCDENRFLNDFJBBDC@EPGAA@EHADCFBDDBDGPBFXDGjDNBPEZGPOT[JHJTVNIDBDHDBHCXBLEHIDAP@HFRRXF@DCRDRB@BAFAFFBDDBnJdBhQDIDADBBEFBHFFCDCDBBADB@AD@@BD@@JL@DBJB@BVJBNFB@LJ@@@","@@BDD@ACA@","@@BAA@@@","@@@@A@B@","@@DD@CAAAB"]],"encodeOffsets":[[[124055,31333],[124038,31327],[124036,31322],[124035,31314],[124227,31209],[123803,31762],[124249,31232],[124252,31229],[124251,31225],[124216,31239]]]},"properties":{"cp":[120.750865,30.762653],"name":"嘉兴市","childNum":10}},{"id":"330500","geometry":{"type":"Polygon","coordinates":["@@DQLOTMFGBGAK@INe@EEA@ADBDALSPORYZSLKFUJMDWDCdU^IhMja^QvqfW@AFAFBH@BAFABCFCINCDCRDdGBABBTAPBNADB\\DR@PB\\BXD^FRFZDxR@CAEUUBIDG@EGCCQ@CDK@EBMCABEAANOPD@FJ@DLJ@V@dHLHLDMpBBDDF@XMFK@MBEFCBAACKEAIAGBCJANULEBCACUMAILGDAJADKJG@[@AICACBIBCJAFKJCJ@BCDGAOBMHMLQDKE@CAQDK@LWDMFKBIBCFCBGMWCC@CSQICWAKBEEAEDCJCJGDEBEIAU@MCwGK@UECEGOCEGAIAEBCEC@KFCFCDOBICAKAGFIGU@IM_CAOC]@KG@OAE@E^WDIEKGCEEIAGCG@@EFIBGDoEMBICEQCECAGGBGGIDWASBWA_HEBQ@MIABADCLABGEAEBIWCEEBCAA@@HCMECDGAJGAEFEACIFA@@GDEGEK@EACEUEEJBNAFGBiGOEG@ABEHODCDAHHJADeDCAEAOBE]IKAEBOAOFKFCFI@GCGGCFGAAMAMCG@AFADEBUDM@WBGFEJC@aDGAOKIKAAGAKBGDEJ@FGHIBIAGBEDAPCFGFG@EAQIC@IFCAEEE@GBMFUBAD@JDHLF@DEDE@IAEBCJIFKPERA@ABCAAGICI@GDEJUNE@cIGAUNcFIHBBJDBDB^FRAFCDa@GAI@]DORGHKDGKGCCAOBAA@CD[LWHIDI@IFMAU@CGCHM@EKWAICEIA@I@MPODIFEDEAEAAUGECOMIQ[SKCG@OCKBGDOD@BDBDD@FCPER@FFDXDAPIFEBCAOOSKMAKBQIIASDCBMNALEHEF]GIICGQMAGDKAECCIAMGICGA]JODM@MAS@WHGBACIWKOI@CIECICGEEEWEG@@BEHKJWDUAGBAFDXCNKHSCEB@LHJBJGNBNGFSHABDPAJCH@^ALEHFRFVELIRALBDAF[CGCEGgYGAQAE@UPBPA@IDEDU@EFAPAFAFBFLFBH@HBBTLJJHBBDAFBJIJMD@FDDABSLIHAHDFJNHDLKF@dFF@LCN@PHZDVRDDBHNXBHTZLFHAFBLLHBHJFBNADBHHFDFAJMHgHMJMHCDATBHBL@VNHJH`LNPLbjAtEJBFJNAFIL@HDJ@JAH@DHFPBHGJEN@LFL@LFDFRbLPL\\NRJFDBNAJ@FBBD@HCFCLBRGHGLMRAFAJDT@FEJ@DLR@RDFPHTN@DCF@F@FFNEV@HBD@FBDDHJLRLBFTHBFPPNFHFHLFJEb@VHdGVCVBFHLPJHBFF@D[JULENDPNBPH@JHPHFFFPDFFFB@JBBRFL@JOTGPIF@HDFJFRFDP@RDLDD@HGF@LDDANFH@NJFBHAJCDCHADCBEGM@CDEFAHDFAJOH@\\JLJ@FCDGD@FHLHCLBJID@NAJFHCN@RKFCJBDBLDRJ`@HB"],"encodeOffsets":[[122798,31919]]},"properties":{"cp":[120.102398,30.867198],"name":"湖州市","childNum":1}},{"id":"330600","geometry":{"type":"Polygon","coordinates":["@@Ve`qpHYNO@CBMFWRkCICCIEACBAN@HKAGBEPQH@DFH@JCFCJSDCACCEAGPMLEFIJCFeEC@ITOH@DCDENA@CDA`BFFD@BAEIBAEGHKBDFAHBFLD@JCHBHBF@VKFEDMTGCEEGAKACKCG@GKGECAIBOAQI@SGaCIICEG@EBC@CQS@E@CIACAHGDIJKFCF@CGBCVK^WFAB@BJH@DCDGHEFAJBHALKH@JCLGBAAEEI@EIGCKLKFI@CACOGGQECKEAICE]OMMGAMLEBWDOEAA@CVcCCA@IHIEKACCIM@ADGLKR@JAHCBECCGCMCQAKCCKAIPK@EIEI@MCG@ECACFIFCLCLBXGJBXLNDXPDAFATcLKDQE]DGXIFBHBHEHAFGBIHAFC@CEKDADBDAD@BCACGBBIGAAABKMEFCDBDCLD@GHMEG@EIGAOBCH@^AJEDKFEJAT@\\GJ@RBLCJBN@ZOFBHDJ@ACACBCJE@EFOEEIACC@GAAKBACDEBCPEFC@AQ]AKDI@AKEDCAIBAFEJA@CACMQ@IAI@GAKBAVCFEAI@IFQ@CC@AACKBKFG@E@OQOKACAGGIEGIGAE@DI@IBI@CCCAAKDEFIFEECGC@K@EBCB@JBLEJKOICGBYNK@KCGI@MFKASCICAG@_F@HFL@DCBU@YFcBGEGKKG_EEBCD@JAFQDK@OOGCMAWAGAI@EA@IIOEUCAA@KFGJaDADCFKLEBOGGGAQBUECOECAAGBKLMFYAACAKBKAC@OLC@CCC@CDKPMBCAQMMQQISAQFG@cKWEGNFLBHIrFJBJAB_HCDAF@BVVJJBDADUNIBCDG@OIGA[@CCGKGAGBEFENKPLZDRALC@MIS@caEBEDWLE@IMGFSDMHMAICKDKAMVEFCBE@CAIOEAEBCFBHDFHL@DOLGHE@IAEBCHJL@DQXC@OAEDOPKBIVIHEH@fFTBHJDDFCDGRCDOACBOEBNAF]RMPID@B@EACICGGMC[IOBGCEEO[GOCCODKFI@MBGAKMQCCECQDGJEFUAESBeICCCCKEAEAOMYQAIKGMWI@AFGGCE@EBEJQFKJIPANIN@JFLJFRZBbFJ@FABSRGDKPBRHRHFTFFDAFKPEDI@KEOBGAGHFJMNABIAQDABEPKDGBKFABJLAFIRCFG@MCMD@GCKGGCEGEGOCCGAGGECGAKEK@GAW[I@QFURG@GECEE@WJABCNBBR@BD@LJV@BIH]@YJGJGDBJFHQHCDENUIKFI@YHAD@JDFCVJXLJDPDDH@F@LCD@LFHN@FABOHG@ELKFBHNDJFBP@FGHGB@ABGAE@MQKMBWLW@CNCDOJKNBFAXIJODEDK@GHEDEBCBCBIAECAABCHECCA@EDKAEDILBDGL@FBHADKLGBCPAHDHSLCFABDH@JD@HCTMPDBADENCBCBEDALJHBPJFBZAD@JJBFNFH@BMBALCBAHCXDPD@HBDFBJBDDDDD@F@BD@XNLCXILBHJNDJXD^CVLFBFCJKJEFCFBNN@BCF@HR^RLHBRLJNRRHNBJ@FCHDD@JBJBBJCFBBHLRD@JCFE@GHAJED@FDPVNL@BGJ@DPFLLPFLEZAHEF@FBFLDBHEDCHO@MRIHBHBDBHJDNDDFCFADAZID@BDNPHD@NLHDDNHDJ@JHRZAHDDHEHBFCF@FDLKN@NKNKD@BBFEZEBIAGBMRBFNHDHHF@TADGFDNBNAFCHCDKBYRGAIKECEAGBKFCJBDJFFJJFHN@BK@ADDBHHRHFABCDODADDLEHJFJJH@H\\@BBCJ@HD@JGFHDBPFV@BBFBDCDMFEJE@CAEBAN@BAAMDADBFDA^BBF@REBEAIBEJAbFB@BRDDDJN@BBDDFBAPFPPBHCHHbGHGHKHCPCN@JDdCH@JEDADGB@D@JF`@FGJADBRHLBBBH\\XldvBFv`r|zrdSLETASXAr@tL"],"encodeOffsets":[[123768,30999]]},"properties":{"cp":[120.582112,29.997117],"name":"绍兴市","childNum":1}},{"id":"330700","geometry":{"type":"Polygon","coordinates":["@@LMPIDCDMX@RIJCJ@PJBPBFAH@BHAHG@EAOIEMCAGLEFKH@PGBA@EGMKEC@KDE@G@CCCOKIIWDUCE@KDCRCRAJEVJFMDCRGEGAIHCHIZI^@JG@AIU@KACQ@AADMBAXIF@LLH@VQREJ@X\\HBL@LFHBFDHHHBDDHPHFDFHHDL@HNCNDH@DEJQBEIKBALEHALCFOBARCJBBANMEIHGHBPALFL@FCJOBEECSEGEGQAQLOHCTQBA@EEIAaQYIEEK@IJMBMJOLIREHKH@HBBBEH@BXJHNJLRBNZBPBFLFDDDDfJTABFEVIFCHDRDFRDLNHBNAJ@LEPCDDHPP\\FFHDPA\\JNDHHJDBD@FJENO^QBEAMPFDAPBDCHQDCCEICAGES@eFGJGJULAPOFCPBD@RW@CIKDGFAJBF@HGPK@CGKCEAGDEFAFBJPDBF@DAFENULBLCJDNBNGTCHEJNF@XKFCFAdbT@NJD@BKCQKYLOFMFEHAHBHLDD\\@HBPJH@DCJAVMBCACIIUU@ABEDC`GBAAIEIJqAGEKHMNIAAKI@IGE@AJKOKSIEECICC[UQGMMGMIAEI@ALODIDAHHF@LEHMPA@ICCIEI@IBIJA@IUIIGIQCMKAEFIJEDEDGAIEI@GUQBARKACCCGBAADSNOHCDDDVBBFBFCBMDCJA@CEIAKDAFFB@DG@KDKGCG@@ABCD@FIBICCOC@CCEEASBKACH@FA@EBKESAGGAEBUEOAEICGMAE@KHIBEAMGEEIIEIImIK@KGMCCBIKICIECEACKKQCGGICS@QJC@ECIBABCF@HBDD@DDEDA@MAEBIJDFIHCEEGBEAMKCMACCAGPQCCGAACFCAEGBMCAA@ADGECCCBCBCGGAAGFBHEJKDKCEBSDMAQGGIGACJCVGJCACGOCCH@JEDECEIECAEDC@CAKGIE@IJKAQJQB@FCHEB@FE@CBANQDEF@DGHSHIH@@BHALIBQJBDD@DD@VDFHHBFAFGJEBADDJ@DGCCBIAQBOEE@ADBHCDAJCLCBIICABE@CECE@GI@AHIGIIODAFAL@BAAECC@CFKAcBWCEYGECKOCMQOWIAMEEKMIKCKBCPKBCEIMKI@ODG@AE@ACCCIEAS@AFCBQDOHMAAAACHIIUIII@KBEFKACB@HABG@OBQRBLDBABCDIAKCIIGCg]WCQEELIDIHKD@FBFAHIACDMFGHODCDAHGCI@CAEKICIFKCG@CFIFK@OHKAA@A]KEBGACOIGICIBEAAEGOKG@CHCBICKKDGBCAGCEKUAA]AGACACKKEQQWMACAEA[EO@EDE@GGKIIOSQGE@MDMJIFOAIEEYp[BG@GIKAGAEAACBKFGBU@GAAC@KCCGEKMMKCG@IAESQ@KCGCCYEQAO@[T[FCAAAKWEEK@_DKAWAIDC@IGU@@BAHGHm@E@EBIT@DBF@JCFCBUDOFE@ECEOECCACAEDAH@BABDB@TDNCH@BFLJPFDDHDJAVGFaTEF@NEDM@OIG@EDK\\@DFDHTARETBJFLBRBH@HAJ@PCT@TDDPER@MTALBLAFABIDEAOIMAGEWAQICCA@IBEDCVEDGDIPGB@FCHMHS@KCCSCAMGAC@GCEIGM@GBGFGXMNAHDbABI@@FDLDFZHFFBDADQVBHDD@BCFNB@DMLC@ECCIAAGBI@MGABFbJPFDF@HIHADDFRCDOJADHBXEFHBL@RIJMFGTED@JGRGJEJCTEPKHAF@DDBV@JHHJFJAHGD@HDDADEFAFLp@RBDDABQDEBCBADDATEN@FBLBDIHCXBDFFBHEDGRCDICKBKCC@EDCFDTCDOHKPEDOFO@A`ABABUFEF@NDF@FKFKP@FFHEHDNCNGDODABHBDTAJDFCH@HVPHFFJDJFFJFTHFDDJFDFBBHBBHBBDCLAJFBHBLE^@JBJJBHAD@LBADEF@@D@JKL@DBBbNJBFD@FADEBHT@FELILG@CBCJHTAFBLHJADBFADEDAFCDIDAD@DHFLXB@LED@TDHLD@NADDPZHDB@JCJeN@HIBA@IBAD@FFD@F@FBPDLTGH@FTDBE@KFEAGBCBCLGFGDOCGBGJUEIJQDKFCJBDAJGDG@KBCXCD@PHD@PCFJTXDJDJAHCDLJJDBBFCDCJCL@LHBBPARBHLHBNAHAJINEHBJCF@FDAPADWPABBHBBJBLJPV@RPHRTDBFADINCHBJELBF@FKFCHBLFBF@RBLB@D@HIFAN@DBBDAFBFFFDHCPGDAFAFBJCFLXLJBDAXBFPF@B@DR@NFDDBDCFSPCHOLCHFFJFTFBBNCF@LHFDJBBF@FGF@BJHFRAFEF@DDDAFAD@DDBNDLJ@RGPBLHXPNFTDBF@DBBFLJJBBDJJDBHCF@VVBAAEBALCTMJFF@JCJBHCDBHCHGDAVCZDFHTEBJFBVEF@DBPBTHZCDF"],"encodeOffsets":[[122853,30388]]},"properties":{"cp":[119.649506,29.089524],"name":"金华市","childNum":1}},{"id":"330800","geometry":{"type":"Polygon","coordinates":["@@BUHMBIFATCFAP[HCLADKHEJARDJCJEAGCEII@A@ADCPAFCNEBEGKBENITKFAFBFAJOTMNARNPBHCDERAHERHFBHAFABCAIIQ@CHBL@VCDCBGNADAVFT@FCJGJBD@BABIPFJEFGAMVSHGEMHGLONMJUBGAAA@IFMNCLCAMFC@AE@GEI@AFIDIHMAGOOLMBEFEHMH@HBD@BABA@GBQAGGEACAADGT@\\JfHL@RDHCZQNENBPRPDDJBDLHHDT@\\RANBJINDPDFD@N@FBDFBBBDFBDPNBfZJBJCJBDH@FNFFFHHNBJFDDBLHLRPRHPGF@DBDJPHFCDENIHINEHI`EBAHIDCZEBA@ECCSGEEBCFEDAPSB@HBFGLKBADBHSJKEGBI@IBGJGFGHCFODATJdFNDPJT@PHL@NCD@HFBDFDN@DEXAdTF@LAEQBIBANAFFJ@LJDANKPCDCLKBGZCJV@DADGH@FBBFBDANBDKDAF@DBDDELBJ@RBBDBSLGJCBECCBCB@D@FLNFDF@BD@BGBBBAB@FCHDLJCFGVCLFHC@ACKBAHEDCDOHGCQB@LB^GD@MIIQIIUO@GDGCEBICSGABAPCHCDMCMFGEG@ELOLE@ECE@MFEVEBABAB_P@PEFCLOPGDCCSDEFCD@LDLAJDDCHQFCAGEEACDWJGACAK@EFMBSCCABADCFARCBAC@QKoBEFEBCCC@GHCBGEIGIIGU@CA@CBELGFODSFIHIHQ@IFCHSNEJI@QAKEGWFGABCPIDCEQCCGBGJE@ECIOEaBABBLFJ@HABBDJDDB@D@LIBCAAKADE@ACCAGRUBCACEEUGECEM@ECDCLCDGBA@EEMICAMFO@GAICAE@GISWQGCIKAIGCOAcHMFMAeDCAQWEIIGO@YMKCKCWAE@_LMBGAMME@KHMISAIIMEIGCMCEGEGAKBEAKKYOCGEECICCE@IIMWICKOIGMQA@IJEBGEQ@UIIM@QCIKKAEBUKGEMBMAOHGBCBIEGGEIOKKMG@IACMGGMCAEAKDCDALCDIAEBEHAHABG@IAE@QLGDG@OIIKEEE@GBG@UIGEAGEIA@EBCDCAGHCAE@KDGAAGGI@CAACEOGCICAI@EKBKFAFMGQAQ@CJCBCEYGU@CHEGEAC@S@CDAJBDBDHNCZFDACE@CFCBCCSKIEOEGIS@CFI@CS]IIEICAGBIIIAKGAC@OEEBKKOGUOYMOKAI@IDIJE@IEM@MYMAGGG@UBMEIFANFJAFKLEJGDSAKDWESHAA@C@E@KaIWAGBQTE@CGGAACAKACACHCDGD@@EAABAHB@ACE@EMCGMIFMLGEKDKECDE@ABGBGDCFGA@F@BJJADS@ABFF@FCBGACREFFRLFLDLFNHBBF@RVBD@FBBHBFDB@DEB@AFBDFFBFGLC@A@BEAGAA@FC@@CCE@HA@EAC@@BPHBBCB@ACCCDDLAFEB@FATADID@LOfYLCFAJCDE@ECABBFNJ@FBDPFFCBBADH@D@@DCBEACBFJHBFL@FFPHNEPD@BCHC@FGH@BDBD@ADFB@BBDDBL@BF@BI@BHGHC@@DBB@BGEEBE@@BCB@CA@C@BCECCAEDENC@CBEJGDCBAAE@AAEBAAGDCCMLFHFDD@DC@ADA@B@BJA@DHDB@@AFA@DADHB@DHHCFGDCHAAGICACBDD@DGD@FCA@BDBABCD@DDCCFD@CJB@DIBB@DEFCFAACJBBLBBBMDAB@DMFADDFCDBBEFAFBBBHLABFCDBHCDHDFABB@BD@@BABAA@@CB@FAFBDABA@CCC@CBBDAB@DFHCBAFBBHDBCCA@AFBD@ADDADD@BABDB@D@BBABB@A@BA@BBFABNDBADEBCF@BCBEN@FA@DDCBDDF@HDDDIBFFAJDFAFBBCD@F@D@BD@BBCFEDMCCFE@@BBB@DEB@DBDHA@DMHADEBCAEHCBKACCEBBDCFDBBHLDFDAF@F@BABCCEFDDHCBBCB@FCBABG@@BABB@BDJ@D@@BCDA@GDC@@FBDEBEDLB@FB@ADFBBBABCAAB@BCAC@ADDBA@CA@ECBBDAJCBBDBFCB@HBBA@CACB@FDBAJCDBBB@DBBB@@GHCFGDCLFDGF@DEFEAADG@CDG@@A]BKAOJGBCDK@ODCHGC@FILRLCFBBABC@EF@HGREFE@@NCLEJ@LAHEHEBATGP@HABQBGHA@C@GGMBKCIEGAECIAGEQGE@KCIBAJBJFFTHRVLHDHHH@BCBAFIBIAEBCJABC@ECKD@JELKLELGBEFIAEFCBABGB@BECEBCCC@BDA@ABOC@EBGCA@DABIBGD@BE@OXBDHDAB@HFHEH@DCDMIC@CAEABCGGDECCAMSAHLFD@JH@CF@DAHGCBCEEAECACEGJEN@\\CLGDIJOD@FBDKJAHBDTRCJBJ@DKJQDMJQDKLCF@JJPTFBB@FIHIDIJJV@NDHCHBJEFKFGBCBAB@FJPFdBDD@BB@JDPJJHDHCFA^DN^DD@DCHDHIFADDX@DFJED@VAHIH@DFDH@dIRAFDJLFBFAFI`GPHPAbVN@DB@DCLIJIF@BJBRLFH@NDBHDJJLBLFDFDPALINJR@B]VCH@DBBLCHBJPPV@JFFRHL@F@HFNHF@LIZDFAJGVFFCDGFAJ@FDNALBBBAhBV@DCFCRCFCNCFBLAH@FDFFBN@NBH@BCFKHIDCJCBG"],"encodeOffsets":[[121186,30184]]},"properties":{"cp":[118.87263,28.941708],"name":"衢州市","childNum":1}},{"id":"330900","geometry":{"type":"MultiPolygon","coordinates":[["@@E@IF@DHHAHDDNEBEBANADAACSCEC","@@E@EDGRCDKBG@G@EDGJADBDXVBADEHALBFADGJSDWAEAA","@@EBCNCFCBG@MIE@ABCJ@F@FBDLHVLDHFBZBNIBCBIACAAODCAAC@EHYACACIA","@@GBMHKAIDCBAB@FJFEH@DDDLD@DAHJLD@DGDCHADABGFCZ@@EGE@ECCW@EABEJGAC","@@MBA@@DFFHFBHJDF@JI@CCGEAE@CEA@","@@ABBFH@FDBAFB@BCBJFDAAGLAAAEAMAMACA","@@BDB@FABAACAAED","@@FABAACA@EBBD","@@@CIGC@AFFDAD@DF@DC","@@@AG@BDD@","@@F@@CGAADDB","@@F@@EE@@F","@@DBBC@ACAAB@D","@@B@@AC@@B","@@@BBAAA@B","@@B@@AEI@BDJ","@@AB@BBA@A","@@MBODQP@FJJBZFRD\\DB`BDBLLF@DADGBCACIECE@E@CBA\\KBC@CACGCK@IBM@CECS@CHEDMACEC","@@C@_Ne@GDSRq~ADDNDBFBH@HCDBJFH@H@JA^SBEAGIGACBKDCRGZE\\FL@TKHGBIAEEEE@UBC@ECAE","@@ABBF@DFBBA@ACGAA","@@BAACCAE@@FDBD@","@@@BB@@CA@","@@@FHHDBB@JCDCVU@CEGE@OGCEGCED@HCH@T","@@FBD@BCACAAE@AD@B","@@@DHJLBDADO@CCCE@OF","@@NGPQFIAECASAEDGJOJMDIBCBG@IEC@CD@JZJNNDBFBFALK","@@F@@CEEGAADDF","@@@JJTHDTEDEE[EAQAE@AD","@@DA@AAAYEG@AB@JDDJBBCFBFABCDB","@@DDXPFBL@FEFCBG@GEMOWGEGCE@EDEHENAR","@@THL@BAPOAQECUEMBOAC@KNAHDFHDND","@@FCBAAAACMEO@CBCFARBFFFF@FDF@DCBABO","@@BBD@BC@CAACBAF","@@ADD@D@FC@AA@GAAB","@@J@@EACEBCF@B","@@FABACACF","@@VFD@BCEKAACBADG@EF","@@D@B@@CE@@D","@@HCBCE@CF","@@F@DCCACBC@@B","@@CD@BHCPKDC@CC@GH","@@FCAEC@GFAFDA","@@D@FADGAEE@CBEJBD","@@DDD@DCBCCEKAEDADBDFA","@@JD@ECAEAABBB","@@DBBCDKACCBGN@B","@@BFADFB@MEAAB","@@BI@AEBAF@DD@","@@BGAIAAEDCPBFDDH@@G","@@DFJ@AIBCCEE@EB@L","@@BDDBFAZEbSp]HI@ACAE@}VMDOJWTAF","@@D@@A@IAAC@AF@FBB","@@BABBADA@@DCHDB@DHBBAAAHC@EHA@BB@@EFED@DBCH@DFEBBBCD@@DB@BCFABC@AA@AECDC@ADCA@ABCACAEAAADC@CAAACBCDIAEDC@AB@DI@@DEB@BDBLA","@@CBBBD@BACA","@@DBCAA@B@","@@B@DCCAAD","@@@B@BH@CCA@","@@DBF@HCCC@A@AHADGAADEE@A@AFCAABDDABAFGBEGGDBBGFBHB@@EF@B@","@@FBDADEECI@@CC@ABDFCDFB","@@@BCAABBBDABDDA@CA@A@","@@GBFBFABCAACD","@@BBBA@CGBADD@BA","@@BAAAAABAAAAD@@EHABFB@ADA@A","@@ADDA@CA@@B","@@B@DCC@AB","@@JAAACBCAAD","@@CDBBBAFBJCACKB","@@E@FFFBF@ACA@CABCA@CB","@@DBBADBBAEGA@BBAB@A@ACBEABB@DDB","@@@AHA@CFABACAA@EA@@CBE@ADCBC@@DEBABC@@@AA@AC@@CEDCAAAAB@BBBFADBBHBBFCBDD@@EB@BBBBB@@AHCBB","@@BBDADDBBCMC@C@ABBF","@@BBDAEECAADDB","@@JBBDHABACA@EB@D@D@DEFC@A@AC@CCC@GCMDGCCDE@ADJH@JFB","@@DBB@@CB@DCAGC@@FEH","@@EFBDN@FBHKFABCF@DEAAAAGAAFCBCDC@ECADED@B","@@FD@CDEBBF@@AFA@C@@CBC@ABAACBCBCD","@@@DFAFBDA@CCADCGCEIABCBDJ@BBBAB","@@AAABBDCFA@CCCB@HAB@BHBDCHEAGDA@AA@","@@DACEDBDABBJC@AC@@CJADCBCG@ABIBADG@ED@BD@@BGDFF","@@DDBBD@FBB@DBBACKEAKAEAG@BHHB","@@C@@DDBHBBAD@AABCAAEBAAC@","@@AD@BHFHADBBAH@AAG@AACAE@CC","@@@DCBDFHBBADCC@@CGC","@@KBCHB@HABDHBDDDABAIGFC@AE@","@@L@BEJDLEJ@@EBABCIB@DABQACCE@AA@CFA@ABC@CICCEE@CCCBUTE@EJ@HBDBBH@J@","@@fF[EyBOHOfuDCRGZCzWT@FCLQ@AEABCPGBC\\MV@BAAKBCZGLBDDDA@CCKFGEGAAODCBW@YFCCMBEDaR]VEHubEDQBe\\y|IRCREEbGNOZ","@@DACAABBD","@@D@BDNJFAF@FAEO@GIEQBGB@DDBAD@D","@@H@JDBDFA@FDB@BHB@GDCGABE@KBCEAAADA@AD@@CE@EDG@CBE@ABUHADG@BBFBADDFHABBD@@A","@@BBDECBAB","@@EFCTOAEDEAABAHDFADBFAD@B@DBEHEJ@H@DAFA@AAABECGBUDC@A","@@BBAFBBDC@EAAAB","@@D@DDABBBFACGEACB","@@ABBPIVPDBCBGBAAAAOAGCC","@@D@@AFA@ACABAC@@DCD@B","@@FBDBBACCBADAB@DBBAAAHCDBHBFCAAEDCCE@ECCFEA@FIBBBCB","@@B@PAGCCBEB","@@LB@BD@DCFACAI@A@E@CD","@@BBD@B@@ACCC@ABBB","@@FDFB@DB@BCACC@ACG@","@@BDDBBCEC@@","@@HD@KA@ADC@","@@R@BBAFBDHJJFB@BGDBFACGBAACHAFGAGF@BDHHBA@CBAAAECBEKA@ABCAAGBAFCBC@ECA@OPGAG@@BCB@D","@@FBFAFDDACMC@ADCAEB@BD@EF","@@BDADFA@AFAFCAAG@ACA@ADC@BD","@@BHFBD@HAAGCB@BA@G@CC","@@BBB@@EAEE@@HDB","@@D@DEA@EBEABD","@@BBD@CEC@@DE@BBFA","@@ABDAAA","@@BCCBBB","@@B@BB@ACA@B","@@AFBDF@FEJ@DBFADCBEHGJA@CEA]AACC@EDAFEDAHBD","@@FBDH@DD@BCACBABCFC@AGACA@CCAABA@BDEDBBAD","@@AHDDD@CHFABBHDBCCABEAECB@IDCFE@GC@ADCCA@AJCAEFBB","@@CJEDAHCB@LB@BANAFABBBA@GHABADWCMAAA@AB@HCFBFG@CC@B","@@ADF@BD@HD@@CNBBCDBBEAIFOAGDAAIA@ADEAEB@JCDC@@@DHEHA@@DE@","@@@DD@BACEC@BB","@@FFDAACAA@G@ECAA@@DE@DFABBBE@ABBDFA","@@ACC@@BB@ABB@BDABD@@E","@@D@BAAAECADBBA@ABF@","@@@DB@BDH@ACB@CA@ACA@BC@","@@A@F@C@","@@BAA@","@@C@@DABDB@DE@@DCBEAABBBDBFCDBJAHD@EACADEA@CBCCC","@@BAFFHAJ@@AACDCDFDBBCF@DCD@DCCEBC@EAAG@MFABCB@CE@EJACA@@DCD@BABCAAAC@@BHH","@@ABAAADFBBA@C","@@B@AA@B","@@AAADCAABC@ABDBFADBDBBEAA","@@F@DCICEI@DABBD@DDB@B","@@B@BAF@@AD@BAFDHBDDDCCEWEKBBDAD","@@BDADFHADBBD@BDAFG@AD@DFBD@BABCLC@BCD@DB@D@DFB@BIB@FBNAFAHFLB\\@JBHAJ@\\JFEJ@@A@ECCB@FCBEAID@@BB@B@BA@GFBDCAAB@TABCA@I@CCCAABA@AOGCIBAA@AF@BCGKKEI@CRFFCDIBCEC@IBADDB@BCB@BFD@BK@@DFJEDCAGEGBGFCA@EACDIAGAACA@AACGBEDCC@ACEI@CBCDCBAAAGCCG@CFI@AFABC@CGC@CH@BC@CE@GGCEBEDADA@EGEGG@EBCHC@IJBDAFDDL","@@B@BBLBDA@CCADCCEEBCAA@BHABCCCDBD","@@BHFBABBB@DFEL@@CABCAA@@BCAGGE@","@@BDAAKBAFADFHBDA@AAABGBCFB@A@KAAGAiAUCIC]SG@CBAD@`DLJP","@@@DH@@CFAHDHBBHBDFBDDL@PO@IBA@AGCCDWD@B@DA@IAIECAA@GB@BBBCB","@@BDNFBAJ@DA@CL@@C@EF@BACED@BEAAKAAAG@CBAACB@FCDICACCBAB@DBL","@@FA@GED@D","@@VPBD@FBF@BAACJ@BB@BBD@DCDE@AFCCCBAHGDADDDAAGDACEF@@CB@DDHBH@@BDBBA@CD@DD@DDBLEDDB@BCLEACMC@EBABGDENOF@DCD@DDBDD@DC@CDBBACEI@BCEEMA@AQG@A@CNSDADBDABA@ECMMKASBKDC@ECA@CDABACCOECBABECOA@BBHADG@CAAAC@CLBDIDa@[DSAODWJg^[ReLQL_JCLGFADDBFABDB@F@HEF@@DDHF@JCBAAC@MPGH@HFBDCDBDFFHBJ@DBADBDTPHBBAD@DHBABEB@DCF@DBDDAHD@LKLHHABD@D@BFD","@@ABBB@BDBD@BEFFDAEC@ABA@CEDIB","@@@BD@CA","@@BHDD@GEC","@@D@CCCFBA","@@BDB@@CCA","@@DFDBBAF@ACC@AA@CGD","@@JFHDJ@HCDBHGF@@ACAG@ACEBEACGE@OECBBDAJ","@@FBDABCAGBAGACDA@@HA@BB","@@ABBBDBD@@BFB@AAA@EC@ABC@","@@ABBBDAHB@A@EH@BAEAG@ABBB@DE@","@@BAA@","@@DAE@@B","@@HDBDB@AMABE@AD","@@BDBBBC@ADA@ACACD","@@DBNBDDBDFBBDJABBHBDAAC@AF@CEBCDBB@BBHBT@LGHBFAJ@FBBC@AICABCA@AA@@ADA@AIBACC@BEC@@@LE@AAAECABBBABEACB@DA@CECDAC@ABA@E@AABC@ADC@AEEC@CH@@CD@BAOCACF@ACI@E@CCDA@GE@AIAAC@BECAEBACCBWRADGN@JCF@F@DDBBDCHDJFFAFCBBBD@@B","@@GAC@KG@AiWCACDEACBCHDFKTC@EDBBD@@DDDDDL@@@@FEDBBF@BB@DDBHEBFD@HCBBBJ\\AFINGBE@MAA","@@A@AF@HBBCRCBDDFB@BCDGEA@BNFCFBFDFJCHBFBDLFFABCDBBFAFDDBHJBBABCDBD@@A@EIIDEACOCBMACGA@ABEFC@AECBEAEICAGICEIAA","@@FBBCDC@AECC@@@BDAB@BCB","@@B@BAC@@B","@@HDD@@AECE@","@@BDD@BAF@AAIA","@@ABD@DDFABDD@BFLA@AEAAGGA@CC@ADABE@","@@B@CABB","@@B@AAA@@B","@@B@B@CA","@@EBFBDFBA@AD@AAGA","@@LBBBD@AEC@K@@@@B","@@DHBDGVBFF@FMBEB@BDFRH@BKDBBAD@@GE@GGCAIMCAI@AB","@@DB@DFBFMCAEBCBAB","@@F@BECACF","@@CBHFDB@BDADB@CE@EECA","@@BA@AC@ABB@","@@D@@ACABCAIAD@HABBD","@@BBD@ACA@","@@@BB@DA@ACB","@@B@AAABB@","@@B@A@","@@ABABAD@B@FD@@BBBBA@CBABEDCAAHAAC@A@EF@@AACE@GFC@@BDD@FCB","@@BABEGA@DBD","@@BA@CA@ADBB","@@BA@@","@@@BF@BABCIEEB@BDABF","@@BFH@DD@DD@DCCCACEACAEB","@@B@@ACEBC@AE@ABBB@BDF","@@D@A@","@@DA@AGCDH","@@@CA@@DB@","@@BFJ@@ABA@AG@CCAD","@@B@@CAD","@@DADDH@BAMAC@","@@F@CCE@DD","@@@A@A@D","@@A@ADDDDBBABBBABBDAAAIAAA","@@@AGAG@@B@DJ@DBB@","@@EBADC@ADBBDAFBLC@AC@@CCA","@@H@@CB@AEBA@CDB@EAAKCE@AFBFFDCFBD","@@BAD@AAECACA@CDBBCBKFPCFB","@@H@NABEFCD@LEBECGCEAOAGGEGM@CBEIIW@GBCB@BBDDD@FCHCFGFMACB@FEBABBDAFBBNPJHNCBB@FNH","@@D@FC@KBA@KAAK@GHANFH","@@CBEFAD@DFFD@DLJBB@BAAGBCFC@EACQG","@@B@@EHC@EEEMIAB@DGNCB@DBBH@BDF@","@@A@G@EBBDDBABFDCHCB@DCDDDF@DADBFADEFBFC@AH@FG@CHCBCACCEEAEAEBQJ","@@HABERDFC@ECG@CH@DCAEJMLA@AACBCRBLAFGB]FYLYDQEQGE[OYGWKMGSKQB]HAH@PCBUJCLR`AjERATLRPRBFAHEFAHDHHFN@PAFB","@@D@@ECEAC@ACBA@ADCBDFH@BD","@@D@BCD@BGKCAAEACD@DABAFHDF@","@@DB@EC@@D","@@@CAAACEA@ALABAECJCDE@AQDAA@A@AIH@FABBFEB@BBDDBAFBBF@BDDBB@BCAA@C","@@B@DA@AAAED@B","@@BAA@@B","@@HCBCGC@FEDADBBDA@A","@@ABBA@@","@@BA@ACB@B","@@AFBDZLLBJADCDIAGAGGEEC_DAD","@@ADDBDCD@BDDBD@JC@AICACDAJ@BABCCABEACCAEDE@EHBFCDI@AAC@@DHB","@@AVBFDB^LDFFA@AF@XGJ@LBVHFADEFADAEMEBAAAA@GFC@CCA[CACII]EMBQDOH","@@IFGHBFBBJ@JDF@JCJCLKEGCAYCABCD","@@@A@A@D","@@@BDDHACA@AG@","@@AFCDADJ@CCH@@ADADCBC@CDA@CCAADAA@AA@GHAD","@@CFBBBA@@BC@A@@","@@EFD@DABACA","@@REHFJ@FAJENCJABA@GBANGLDDADIFE@CCCE@KHCA@AAAUBACCE@CBCP@JALGACCADI@AAAIDACBCNQH@FEFAFG@CCCOBCA@MGAEBABAFGDOLEBECKDOLQNgXEJAPGHIDK@EHKL@FDDJJNH\\FZA","@@A@@DFB@AAAF@DCC@E@@B","@@D@DCHABEFA@CAAEDE@E@@AGB@DCBFF","@@GF@DC@@BBDFA@BFAAFDBDABBBABAAAJEDEACCB@@@EDE@AC@ADEAEBADA@","@@FAC@CB@@","@@GFBDHDFAD@HFFC@CFCCCEEOACD","@@QDOL@FBBJCBBDBPG@DFBD@BEJE@AA@CC@CM@","@@D@JABK@GGAKBE@FR","@@DBH@FBHEJ@BCF@DABCAAACEAABMBSJ@DC@","@@FDLAFEACLGAAEBABEAG@BDC@@BA@BDGD","@@FCPATF\\@LQHGRYbOJMFGTADEBE@EICCEBMFGAYCKS]AGAOKSEAMFIBUCUGMAC@ufYNXQHOJSJOBE@oCSGGAEBEBCFK\\GJC@YBSCUBMC[OWGECUDABELENQ`[bIJQHGFEPBHFJLFHH@FGFBJEZCHSXAF]fIRILURCFAD@HBDNJFFHBDD@HBDF@VKVGHGPIPGhIjOXCrNpHVCHAPGBCDO\\KNYFGPKH@L@DBHFB@FCN@BDD@DADELGAFBD@DEF@BCCKA@E@ACDABC`aH@BPBD@UFC@AEC@I","@@@BFFDBB@@CAA@CG@","@@ADDBBBBADDFAACIC","@@BEHABQBC@AOCCEGCAIEG@GDMKIKBCBEPDNCF@NCF@JLFBDLLJ@LFD@","@@FHD@BAAA@A@@ACEB","@@BDN@DCBCACIACBEF","@@@BB@BAA@","@@CDBBDBBBEJDDN@DABEB@JFD@AEBABABFDABACAHEEEACH@FGB@BDD@B@@CBCNABCD@DCLAFCH@FBZ@BE@CGB@CBEC@@CDABCE@ID@BBDCBAHKBCCCDC@GDGACBAECCDABAEACHCDI@C@AFCBGHC@ABE@OFADGBAFA@","@@D@BA@CHC@CFA@GHA@AC@BC@CEBAJCBCCCDC@BDCDDDEDBBAB","@@ADFBFADCBBFAF@BA@CDA@CE@ADEAAD@BIBEB","@@B@NBBAFAACAABAEA@FMD","@@B@BDD@BCCGD@BDDABDF@DGAAGBCCC@CAG@EJDB@DD@","@@FDHAAACBECA@@B","@@F@EA@B","@@@BB@AC@B","@@B@BAFBCKCC@EEAAACDCCEBC@FHDABBB@BB@HBBDB","@@@DDB@BD@@GC@BCCCAB@B@D","@@EAADBBFABB@D@BF@BAVBBBB@F@FCDC@CHEHKF@DBDA@E@ELG@C@EJCH@D@BCD@R@JDJ@@B@HBDFBJADIF@@B@HBBHADHFBDABAHADA@CACICG@A@BGDGLAFABC@AEAAEECC@CFE@CAAHCBEEGBCABIEAGFE@A@@LE@IKGCEFAFCBCCG@OCGEAA@EEEAAEFCHC@AECAEBBF@BIAA@ADKCAA@CAAA@CFKDAHHNLBFFBFFFCPDNADODBHA@CAE@","@@ddDHD@BC@CDCDEDARFFBDBDGFCXEDEBEBADBF@B@AHHDHADCBBDBAFCBBB@DJ@ZKBCAEKG@CJGAIBCL@DIACSAG@ADG@EA@AFG`CHCDEAECCAAFECEFCDG@CEEGAODCACCDIAEMBE@CCCEG@CCAGDE@CEA@C@CFCZGDC@EEADMECDCF@BCAAQAGDCFGAK@KFOREJBFMV@FNNBDBHENBFADEHSBQLADFF@JOHI@CCC@IHMPANBBBBBH","@@G@ADCJADCBC@IGICEBKHUBEDILCF@FDL@FCHKLIFOFCDC\\CDG@M@GCGMQKK@MJUJC@EBCDAJNRTlNpHJLHH@RCPFNBXNHDFAFABCN[BSDOLOTSTIVGJCdaHUDELMBAAEeGE","@@M@YFGDCHCDC@GGSDCACEI@CBBFADCAGEGBCBGJGBE@CAGQGC]CEAQCMDSHgLCHBNA`DN@RGV@DFDNDNCHIDCHCNBHFH@J@\\IfAHHJDJHDHDBHGLCBC@AACKAAEEEDGDAFAB@DFF@DA@GJABBBJFBJARKRCFGDAHBFABCAAEGAQFODCJCFE@CCEGA"]],"encodeOffsets":[[[125592,31553],[125785,31436],[125729,31431],[125513,31380],[125220,31372],[124537,31340],[124506,31329],[124505,31307],[125893,31167],[125897,31168],[125883,31159],[124501,31009],[125321,30959],[124824,30955],[125250,30903],[124763,30776],[125345,30768],[125329,30690],[125223,30438],[124966,30480],[124943,30426],[125227,30406],[125000,30713],[125027,30716],[124972,30702],[125111,30698],[125040,30703],[125039,30683],[125077,30686],[124958,30674],[125078,30682],[125027,30664],[125048,30669],[125064,30698],[125068,30695],[125084,30691],[125064,30704],[125079,30702],[125081,30705],[125081,30707],[125111,30703],[125130,30695],[125033,30722],[125022,30700],[125011,30693],[125022,30689],[125015,30677],[125001,30671],[125007,30678],[124986,30663],[125150,30684],[124999,30698],[125620,31590],[125643,31573],[125643,31572],[125745,31432],[125693,31446],[125730,31529],[125714,31535],[125703,31538],[125702,31547],[125684,31550],[125674,31529],[125608,31495],[125600,31508],[125586,31510],[125613,31524],[125610,31532],[125610,31549],[125576,31562],[125367,31425],[125368,31430],[125355,31419],[125420,31408],[125467,31403],[125396,31360],[125364,31357],[125463,31374],[125296,31335],[125268,31330],[125072,31297],[125086,31313],[125062,31319],[125076,31346],[125008,31331],[124897,31529],[124985,31449],[125194,31253],[125264,31252],[125413,31487],[125411,31468],[125387,31502],[125330,31504],[125329,31479],[125324,31335],[125239,31232],[125208,31214],[125307,31216],[125352,31216],[125205,31165],[125387,31167],[125393,31167],[125390,31157],[125407,31139],[125431,31141],[125440,31136],[125447,31171],[125457,31168],[125471,31164],[125900,30894],[125900,30893],[125821,30883],[125707,30861],[125662,30900],[125649,30923],[125626,30916],[125580,30930],[125537,30934],[125531,30928],[125513,30934],[125511,30945],[125501,30944],[125500,30952],[125503,30953],[125467,30947],[125417,30956],[125434,30972],[125435,30970],[125408,30967],[125381,30973],[125296,31008],[125254,30976],[125262,30953],[125205,30948],[125199,30997],[125143,30948],[125112,30952],[125077,30963],[125095,31058],[125023,31052],[124956,31037],[124964,31009],[124986,30973],[125015,30968],[125089,30961],[125059,30944],[125011,30936],[125055,30889],[125148,30909],[124961,30933],[124961,30930],[125097,30855],[125081,30847],[125083,30915],[124995,30904],[124885,31015],[124823,31067],[124856,31080],[124846,31055],[124860,31048],[124848,31037],[124821,30952],[124826,30950],[124827,30956],[124871,30917],[125222,30821],[125218,30798],[125246,30814],[125269,30809],[124817,30938],[125301,30822],[125255,30776],[125397,30784],[125422,30777],[125428,30777],[125417,30772],[125366,30753],[125360,30766],[125360,30769],[125345,30767],[125339,30759],[124643,31303],[124493,31316],[124504,31013],[124521,31006],[124541,31006],[124567,30982],[124510,30987],[124515,30972],[124527,30974],[124643,30990],[124642,30971],[124768,30821],[124784,30818],[124789,30840],[124810,30816],[124867,30838],[124897,30786],[124909,30789],[124906,30823],[124755,30788],[124802,30809],[125391,30693],[125392,30676],[125404,30669],[125401,30663],[125411,30646],[125373,30583],[125362,30591],[125465,30595],[125466,30595],[125224,30650],[125299,30556],[125218,30578],[125191,30582],[125169,30592],[125179,30577],[125259,30549],[125322,30506],[125262,30499],[125200,30562],[125142,30543],[125161,30525],[125123,30526],[125090,30520],[125097,30515],[125124,30501],[125127,30481],[125131,30441],[125159,30453],[125192,30787],[124970,30475],[124978,30470],[124968,30474],[125040,30389],[125162,30429],[125222,30400],[125141,30417],[125167,30396],[125164,30373],[125160,30361],[125151,30350],[125095,30317],[125096,30333],[125077,30311],[125088,30331],[125079,30341],[125366,31477],[125267,30657],[125115,30363],[125369,31139]]]},"properties":{"cp":[122.106863,30.016028],"name":"舟山市","childNum":251}},{"id":"331000","geometry":{"type":"MultiPolygon","coordinates":[["@@BDDAACAB","@@A@ABDBF@@CC@","@@FBJ@AAQE@BDD","@@CB@BHDBA@ACC","@@WBA@CD@FBBPL@B@DCDADBDDD@BABCAOCCD@JDBP@DBJHAFBDTFB@BCEIDCDIBAD@LBHAJ@BCIKEMI@@EFEAEA@I@C@OG","@@CBDLDDH@DBDFBJBDLFDHRCBB@DDBT@JBF@DAAGCEMKOCEAMMAAEBCHA@ECCEKAGG","@@@RH@BAAKBOEACJ","@@FBCICBBD","@@B@AEECEA@DFF","@@EHABFH^DFFDHJHDBD@BCCOCEIAEEEAGGIBGA","@@CB@BBLFLHHFFPDFLHDDBBAHMKQCAGFG@GICMOG","@@BBH@D@@AAEEAEB@B","@@@AAAC@AB@BDDDA","@@N@BABAOC@DCB@B","@@BFBD@BCA@@@DFFB@BACI@CACC@","@@D@CE@CGABJBB","@@FDD@DCECAEAACAAB@F","@@DA@CC@CBBB","@@ABDBDACC","@@B@@AC@ABB@","@@@ACABD","@@@@B@A@","@@DBDACECB@B","@@JABABCAEEAEBOIE@C@@DDDDDJBDJB@","@@JBDA@AIAGEC@ADFF","@@FB@DD@@CDBHDDAAAGCG@CACB","@@BB@AA@","@@B@@@","@@@BDDDAAA@KADEA@BBD","@@BAAAGDABB@FA","@@AFBBJBDC@EDA@CC@CBID","@@BB@DMH@DBB@FDBF@FBD@ACBCDADBBKFA@AEA@GCCE@IH","@@BDFFDAB@AGJCBCDBDCCIA@C@BFA@ADE@EDGA@BDDAB","@@DCLB@AAEBCCACAIBIF@DABGACDCFDBHEDB@BBBHABA","@@ABBBP@CEI@","@@CHFDFBBCA@AIC@","@@FBBAAAECCBBD","@@@DFBFAFBDACEGACBABC@","@@@@BDF@ACC@","@@A@HDB@AAF@AACACB","@@BBB@AA","@@ADD@BA@CF@BAGACD","@@@BFDD@HFDA@ACABAAAI@EC","@@DHD@JFJAAAIACEIC","@@@KIG@DEB@@HFAHBFHBBFD@@CJ@@CMC","@@A@DDCB@@FDFABBD@@FF@AFFF@DE@ED@FFDL@FFEFHD@DIDCB@BHFJBBBDDFAD@@EH@DCGIBAJ@DA@AECOBA@@EAC@CDA@AIE@ADC@EMGEASKCA","@@@DN@@D@BI@ADBB@BGAABDDFBBHDC@FJBB@@EDA\\DPJF@@FF@HJBBHCZ@BCAAE@I@ECGBCC@APAECEAIDQECAGIAACAG@GGBCF@DC@EDA@A@CE@ACGA@CE@ID@DDDABK@EAE@@BDBBDDBABA@","@@HDFAGCEB","@@BDFABGC@@BCB@B@@","@@@AHEPBFL@BA@@FHB@BAFEBBBBBVCFCDEAAG@EE@AJ@DEDBB@FADBDAHHNJBFF@BDFABCACOICKBCAACC@CCA@CG@CAC@ADGABHEBAHOFE@GIC@AAE@CAQLABHFD@@BN@ACIAE@","@@ADBDAFBBD@FAEEFGHAD@BAEAAAEBEF","@@AB@BDDDBBFDB@CH@@GI@GE","@@BDHBGE","@@ADDHDBFBFECABCCCGA","@@BHFBBE@ACAE@","@@JD@HHDABFABHDB@DD@@CFDBA@AIAAIB@@AKCCEICC@ABBB","@@@DD@DA@CAAEB","@@@DF@DC@CB@@AF@@CEEE@GC@DDBDHAFA@","@@CB@@HDJBDABE@ABAEEIFBDGB","@@FDABDFBABAD@@GGGGAABBD@D","@@@BDBD@ACC@","@@AFDDFBD@EGFA@CIECBBF","@@ADFB@BABCB@BHBBDLB@ACE@A@AFABCCEDAAECAABAFK@@B","@@ABHDFA@ACCEB","@@CBFDL@CGC@AAA@AD","@@ADDBJ@AGCCCD","@@B@AA@B","@@B@@AC@BB","@@BBHAAAABAAC@","@@ABABFDRHFA@AKI@AHA@AAAICEBG@@FFB","@@BB@DHBBA@AB@EGCBCAAD","@@HDDAEEG@@B","@@E@@BDDHBDCAGE@AD","@@F@@ADABAC@ABEB","@@BFJ@@AC@ACE@","@@KEBIDCLHDADE@GGI[SEEDEIKCM@GFKBMG@MBC@CQKKHQNMBGJEEGIEEGHEJC|EZDPADADGBCLAAQBEJSPMHG@GDEBAFBDA@C@AFBDDDAAAMK@OBWAMEGDIP@NG@AECFILCFGLABGJ@HBAJFF@HDFGLBBNBNCBA@KBAH@DHLPLHPDLJDHHHCDBFEF@DFL\\n@FKL@HLFNDVRFADATSHILGAGDOEEAEDCDCDAPBFBLATDb@LAJETONGPApEbGN@HHZdPXFDJDR@GLqDC|_\\QDE@G@KK[GaDUDEFGePIJKFS@MGuDSJKdUPIz³HSBQC_GGICMCiBNRG@IEnGJCJQV{BSAaOuK­GUKSWMkQ·UabUXedPSDAfGhQDGFSFyHSNQ^aFKBOMwVCNEJOJ[BUCIGCyQCCBCDGAKKOMKSIEM@CBEHALBRHPHD@BADSBALHDA@EGC@MACY]M]GOCGBGHM@ECEMEEEAMCGMMEC}IICGEGACDCRKPALANDRCHKHsXYH[FY@ICKEGIGMEIeYCGAGBSCGQWwiKKU]E]MWCYEGUIAACYCIGCOEUAMDSZiTIDW@ICEC@E@IFQJONQFODMAWOiIMWMYYQMmK¿MSBaDIDGJERCT@ZAP[°INQN`RZbNB\\DZ@VBX@JHNJHfHr~NVFNHC@FCAAHNlCNKJGLHBBHFEHBND@DCBAB@BLJDDXAND@JJRAHBBLDBBKJGBYROBIAA@AD@DFNFBAFCDSAEH@FCDALEFHFABKDOJ@B@LEBEBG@AFE@CNGRC@CFBF@LEBILKHEJEBC@CCE@ADBDCBEACASAOVOHG@GDCCGOMIIM@M@EEKEGGCCEAGBIAAIEQ@WCKBKFE@CCACEBAACCAEK@CJCDICGBG@AA@ICAIB@FGBCFEDIAG@GDG@I@GPGFBFDFBJBD@HCBMEBCDGEGIDIF[DE@YSCECGKCOAI@IFG@[DEHEDEF@F@H@FMLIAG@EHGAGJCFBFJLFLDFCHOJGHALCJmLC@EFADDFBLEFKIIBILKAKHC@I@GCC@CLDNCBGBEHMDICIIIAM@WPC@CAGIA[GIKAGGWAKCODEFIBMIGAEA@CPO@EDGMCECGFE@EFGECEEA@AFKFEAEBM@AEEGAKB_@UACCC@CBEHIDE@EEAEQBEFOCMTKFMDINIBMFGCMFCDAFDDGJELOLE@CCA@C@KLC@GAOAMCIBGEAOK@IKAMHK@AGO@CDE@CCKA@IBCABGEE@CDEAECAIKBAA]JICCKGKKEDCACE@CHC@CGMEBCJEBCB@J@BA@CNEF@JGHEBIEC@CFEBoGKN@FDDADC@SFEFAFEHCBEAEKGOAAG@CDKDABBF@FELDFCHAHBH^VDFJLFAHED@D@@JHJAHCBCAABADFFRND@RILCZNLCLGD@DBHLDLAHCDADFF@FGHGBEBCHBH@DADGDCFQDIPFHF@DBBRM@EHE@QHSTEDAFBbFPLPNDHFLCLJ@FCFAFBJCBIAEABLHDNDDDLBFFHF@BADDN@BCB@LBDAHLRLJLTF@HCL@D@FF@HJFBDADCFBHNNBTLNRFHJPHPBTCFAJDD@JCFIAIHCBBHHADADDDFDCH@BBBNDHABFEDBDHBDDORBHDDNBLDBNAFFHDFJGCEJIFANBB@FCCCC@AC@GDEBAJAFDD@RIR@LDHHRDLLBDDFJFJDJLDANDLHL@nJJJJFFJHFBNAFGJ@LBFHNJDFPBFAVBFHHTBLFHA@EDGLBTAFBDF@DPDDDAJEJC@AD@BH@HDCL@LCHA@EECBBLFJ@DIBCDANEDEAAACUCCGDMPCTBBHADDBDQLABVR@HFJBJADCHMJAF@DBDLLRDHJJJJVB@LILALBFFBLOBGNCBKDIGCBCLKPFJJBHNNNRH\\VDDDJFFTJPLIL@BHF@JLJBBMJXFdLH@RETBRJNRRNDBNALODCD@DDD@PKD@LBLADBBBEZKNALBHDBPFFDAVBRHHPHFALKDEBCbCHILEB@DBFVJP@JFBJ@HBXBNBHDPPL@RCBE@IDCFA`FLHHLHFdAZEV@DA@CEK@G`EH@DBDJBTEL@NHJLDL@ZMHAJDLPFIAK@IDAFAL@D@DHFFJEFEHA","@@BDFB@CECAB","@@DBBAACC@AB","@@@D@@FB@EC@","@@@BFBH@AC@CA@G@AB","@@DB@BF@ACEA","@@AB@BDBBAB@HDBDCBHBBABB@BFDDAEGBCE@ACIAIC","@@KCABAH@FDDCBHDBBG@ABAAABHLFFFB@CACDICEH@DCAA@AAA@CAC","@@ECCDEA@BBDD@FDD@FDD@@EBA@EE@@DA@","@@HBFC@ACAAABACEAB@DA@@BEDDD","@@FB@@@AAA@ACB@B","@@ABD@AA","@@DDF@AIGB@D","@@@B@BBA@@","@@B@A@","@@BLDBBCEGAA","@@BBD@ACC@","@@BDHJPDP@BAIEKCAAGAECC@","@@DABCAAGB@DDB","@@DBADCBA@DB@BEAED@BFBBBF@BB@BB@@ABAH@B@JFJ@BBHA@ACABCG@AAEA@GCAGBACEAACCAA@AF","@@B@BACC@D"]],"encodeOffsets":[[[124668,29416],[124640,29408],[124660,29389],[124850,29221],[124815,29155],[124795,29107],[124867,29125],[124840,29096],[124246,28812],[124259,28762],[124419,28746],[124698,29479],[124716,29490],[124567,29231],[124569,29210],[124821,29091],[124838,29076],[124787,29411],[124785,29380],[124715,29328],[124717,29331],[124720,29337],[124757,29347],[124741,29298],[124738,29288],[124786,29298],[124674,29303],[124722,29296],[124669,29792],[124608,29824],[124607,29815],[124608,29795],[124616,29787],[124593,29760],[124603,29758],[124592,29764],[124700,29674],[124690,29677],[124687,29685],[124719,29657],[124720,29654],[124727,29654],[124770,29531],[124727,29442],[124749,29455],[124762,29462],[124774,29424],[124787,29390],[124820,29358],[124672,29380],[124843,29139],[124776,29106],[124828,29078],[124646,29057],[124639,29082],[124563,29031],[124605,29069],[124608,29066],[124600,29052],[124567,28976],[124583,28979],[124579,28970],[124599,28958],[124606,28949],[124615,28944],[124656,28946],[124626,28921],[124629,28928],[124562,28929],[124554,28903],[124568,28896],[124584,28889],[124487,28924],[124478,28927],[124470,28955],[124103,30026],[124512,28921],[124531,28926],[124333,28888],[124332,28884],[124311,28806],[124301,28795],[124325,28754],[124327,28725],[124328,28713],[124402,28804],[124407,28807],[124403,28772],[124440,28777],[124448,28781],[124447,28741],[124449,28742],[124053,28686],[124848,29394],[124846,29397],[124325,28786]]]},"properties":{"cp":[121.428599,28.661378],"name":"台州市","childNum":96}},{"id":"331100","geometry":{"type":"Polygon","coordinates":["@@EC@KACBEAI@EKAMMBGDEFCHKAMBGEKCI@ECAQR@BBHSJQBGDECEE@OACBCBA@AACKAAEBCDKFGDAFBDABEIKKC@EBKAE@APGR@LCBADI@I@A@CBMKMQEBEVGNFPABCAGJMVCL@JOFCZEDQBKBEFEJ]@KIQFIJAHADAHSAAGCAAIIGKEIKCCGAK@KD@DBREBEFCDIAEQCIECGAEBADEDCBGDCEIOBMCcOAA@GJETEBCJCDABCEIBCJEBGSSIOCBKIE@GBMCOGEGBEGC@GDALEBGDEBECMCEEAAAEBMCEDG@CAAC@ECCAGHEBE@YIEEYIMAEAG@CDARAHADGOECGEGIIIC@DCRABGBUCGBIAM@ecKCK@GBEFDH@BGBOEEWBIAGGI@C@CECQCEDQFGAMBK@GBEFCD@FCB@BAACFKDIF@LCBBL@LAFEHGDMACEEBA@C@IDC@A@CEEAIBGDE@CDSDWAKA@DA@CCAIAAEAOMK@CJA@A@MGEGAEHG@CCGCAi@IAECGMMCIBEBONC@AABGKCEGFABBLAFHNCDHF@HCD@DGLABAAACGBMCEBcIIIOGIGGCGBIAEEC@CBS^CDEJA@SO@CBGAC@OCCCBCJINGAIBYICIhg@AOGKMEQQ@MJGHEDG@KAIGGAMMFCAKFEHGF@DIEQM]IEACBEFEBCGK@C@YFEJA@EOGCE@OHG@AEC@CDACI@CECQBAB@F@JCFCAIKIACECDAD@@CIFC@CIKACQOEGCGQBCAIMGESECBE@gSCGAOACGCGGEAAEAAOGK@EMFG@SDCFA@ACGGAECGYIGEAQBIBADEDEAIBG@OEA@CIKCKBCBEFCBA@CEKEAAGDGEC@CBGAAB@B@BAJGBCHG@AEFK@ECGEAUDACAIACECEBEDEBEGM@@IC[BEEEDGAGFM@AACWQM[F]CMKS@QCKQY][KCOEIJGLCN@JILKFk@eIKEUOSSIGEGDA@I@EFABEAAEA@ABEC@EGKGMCKG}YMGMc@CAECCAAEIEKKAEBGBGCEC@F@JAFABEC@QICAAEFYCOHIBECCCIBIAEHMFIFC@IEI@A@EFECEAIFCAGCCB@HEFKBC@GCE@MJ@BBHBJDL@DCDGFADJDP@BDETEHGDODKIMEIGECCEGCC@GBGLEBE@KICAQLALUHCEC@EDOTKFEHGBWCM@GFGHOI@EDCFCFE@CCEBEAGGCMBOEG@MIDABCBEIUECILUFCHEBC@MAI@CAQAKDEDBJITGFIAAF@DDD@LCHCHKCCDDD@DEBAB@DBBALEDAAMCEAIFAFBJDFHBLVZFNJJRDNHFRDDFGDEF@L@NAFHHAHDJBNHFBJADCBI@EDBNABCDFLAJILGNOJKLAF@FGJAD@FHFDFBFAFILBHDBN@VAH@BF@DGJBJE@IAILINEDIDWrILAPABI@CFMFDFELFDJDF@DBAFELADBLAFKHEHERDFADAHQPDDDDBNBFFF@HCJMFALLLEBEDIL@P@DILFH@DcD@BBDFDAHgRYFABKDM@G@ALafIDCF@LDPAHDDGLEH@TFTJPBFCJCDKLIDAH@^@BJ@HLNHDHFHDBDJBBNHLCLFDRFFLDN@JAD@DBHLTJCDBJCPFNFZANCJIHUHI@OGQCG@AB@F@FV`HFLBFDTVTDDJBHHLDJADGFGNCDKD_@GF[HQH[\\@PAFYF@LBHDJ@LCFKLEDKBC@GEGBGAALFF@PBDLHJBJJHADBFJFFTZDLEJ@DJTFHFPLJDTADED@DDFCBYEMDCGCAIACB@D@TBDHFGF@DHVFZADID@DBRHRENEBALFLJ@DBDJPHDFBB@DLTJ@HCF@DBHGDBDCFAB@FJBHHFVJH@HAF@FFJLTJF@XOF@JBH@BABGFGFAJBDCBKDCLCFBDBHNNHBD@JNHLLJPHFFHAJADGHBPANFNLHAVBFLLDJ@RJNVJR@HFFAJIB@NRJHLPJDNXJJF@DDDJFFDHZPLLFBLAHBHFDFDNJHNFJJTBNJLGF@NNHBNA`KF@XBLDLDZNP@JHFJRXDBfCNBNEdGPBHDBJJLHDXRJT@HBFJDHBP@NEDBNJFFLABCFOJ@DABCE]BGNMHWJGPADBJHDF@HBDNHDBDTLDT@NGDG@EHAJOHCFCDUFCJAB@DDRJXBHFNBPJFBDAFABCBEAIBKNSQ@OFCC@SDS@OBI@GAGAQEKAIFSBQGSEC@CL[FCH@PJN@FC@MFEbSHEBUCICGECIOEK@ADGCM@SCABA@ABGHCFDFDFPFDF@PEVCDADE@IAE@CJSFAF@n@HGBG@AV@JHD@JCXBLB`CL@FFLXBBDB\\E\\SP@\\BPFDDDH@LTRBF@JDHNLLNHFDD@LBDHBV@HALEDABBBFBHJL@LADCBkZFZJFPBJENINCF@RHPTJJHL@HCF@FFPB\\BFBDXNRRLFDLDBHB^BBBLVDFBHADCHLLJDDADGH@PLFHBBAFDJHJPJBDAHLFB^PBNGPAFCDEH@LDJEJDFLDBJ@HDBGDCPCHGNEDCJBBGAE@ELCJGJCFKRFXDh^HDJJLDJBDCBACAAKRQPAH@BA@GDALBFELAJ@JJJVGJBDBBNBPGRCDABET@FBDJDD@BBFL@RCJDJJDHADOLADDLJLLNFFBNXJRPDNLPFDZHBBBDAXBdEL@DDDBFABK@EBCBJPHJGJ@BHJF@FD@DAFDBFHFBFMBIDCAGBCF@PFRAJBDAHD@CCIBCFAHIBEAEGGCE@UCCC@ACRIJABKAG@@JGTGHG@CFERCBMDAF@@EFADG@ERARILBJIF@HJBL@DCDBFFDFJFDFC@IDGPDDHDBHIDUDIECC@KMASMMAEFKACIE@GAAGCK@GDE@KSKIKQBGAC@KDA@ACMBC@AGEEEKACCMCGCAKFBJBDAAIBEDE@EKIKDGEMCKOEOAaBEFCTSRGF@FGN@AQCAE@EGJORCDEHCBC@CAGDGFAHAHG@EEEBCDCBGCKGKCAC@KHKDYMKDQJC@QMEEBCBADBDABGGI@IC@C@GFEBIKCE]UAGBGDGCEFK@EAEBALCDCH@BBHPFLDBDAHGBEFETED@BCCC@ELMtHBADED@JFHADEBA@IFEBI"],"encodeOffsets":[[123278,29163]]},"properties":{"cp":[119.921786,28.451993],"name":"丽水市","childNum":1}}],"UTF8Encoding":true});
}));